<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
    <xsl:import href="_common.xsl"/>
    <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>

    <!-- Prefix for all urls -->
    <xsl:variable name="root">../../</xsl:variable>

    <!-- Redirection -->
    <xsl:template match="/DataDocumenter">
      <html>
        <head>
          <meta charset="utf-8"/>
          <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
          <meta name="viewport" content="width=device-width, initial-scale=1"/>
          <meta name="_root" content="{$root}"/>

          <meta http-equiv="cache-control" content="no-cache, no-store, must-revalidate" />
          <meta http-equiv="pragma" content="no-cache" />
          <meta http-equiv="expires" content="0" />
          <meta name="cache-pool-id" content="{/DataDocumenter/CachePoolId}" />

          <title>
            <xsl:if test="/DataDocumenter/Breadcrumbs/Breadcrumb[last()][@type != 'Module'][@type != 'Repository'][@type != 'Documentation']">
              <xsl:value-of select="/DataDocumenter/Breadcrumbs/Breadcrumb[last()]"/> -
            </xsl:if>

            <xsl:if test="/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Module']">
              <xsl:value-of select="/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Module']"/> -
            </xsl:if>

            <xsl:choose>
              <xsl:when test="/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Documentation']">
                <xsl:value-of select="/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Documentation']"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="Global/DocumentTitle"/>
              </xsl:otherwise>
            </xsl:choose>
          </title>

          <link href="{$root}favicon.ico" rel="icon"/>
          <link href="{$root}favicon.ico" rel="shortcut icon"/>
          <link rel="stylesheet" href="{$root}lib/Google Fonts/style.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}lib/jQueryUI/jquery-ui-1.9.2.custom.min.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}css/reset.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}css/default.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}css/layout.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}css/inline-html.css?v={/DataDocumenter/CachePoolId}"/>
          <link rel="stylesheet" href="{$root}css/user.css?v={/DataDocumenter/CachePoolId}"/>

          <xsl:call-template name="scripts"/>
        </head>
        <body class="font-size-medium">
          <div id="nav-toggle"></div>
          <div id="main" class="cf">
            <xsl:call-template name="infobar"/>
            <xsl:call-template name="nav-tree"/>
            <div id="content" class="resizable-right">
              <div id="right">
                <xsl:call-template name="breadcrumbs"/>
                <xsl:call-template name="documentation"/>
                <xsl:call-template name="modules"/>
                <xsl:call-template name="objects"/>
              </div>
              <xsl:call-template name="footer"/>
            </div>
          </div>
        </body>
      </html>
    </xsl:template>

    <!-- Breadcrumb -->
    <xsl:template name="breadcrumbs">
      <div id="header" class="cf">
        <div id="breadcrumb" class="font-small">
        <xsl:apply-templates select="Breadcrumbs/Breadcrumb"/>
        </div>
        
        <div id="tools">
          <div class="font-size">
            <a data-class="font-size-small" class="small"> A </a>
            <a data-class="font-size-medium" class="medium"> A </a>
            <a data-class="font-size-large" class="large"> A </a>
          </div>
        </div>
      </div>

      <xsl:if test="/DataDocumenter/LicenseTag">
         <div class="trial trial-content"> Generated with <a href="https://dataedo.com">Dataedo</a> (Trial) </div>
       </xsl:if>
    </xsl:template>

    <xsl:template match="Breadcrumbs/Breadcrumb">
      <a href="{$root}{@src}{$ext}" class="ajax" data-target="#right"><xsl:value-of select="."/></a>
        <xsl:if test="position() != last()"> › </xsl:if>
    </xsl:template>

    <!-- Basic data -->
    <xsl:template name="documentation">
      <h1 class="sticky-header"><xsl:value-of select="Documentation/Name"/> – Data Dictionary</h1>

      <table class="table table-vertical">
        <tbody>
          <xsl:apply-templates select="Documentation/TableData/Row"/>
          <xsl:call-template name="customFieldRows"/>
        </tbody>
      </table>

      <xsl:if test="Documentation/Description != ''">
        <div class="element description">
          <div class="html user-description">
            <xsl:value-of select="Documentation/Description" disable-output-escaping="yes"/>
          </div>
        </div>
      </xsl:if>
    </xsl:template>

    <!-- Table data row -->
    <xsl:template match="Documentation/TableData/Row">
      <tr>
        <td>
          <xsl:value-of select="@name"/>
        </td>
        <td>
          <xsl:value-of select="."/>
        </td>
      </tr>
    </xsl:template>

    <!-- Modules -->
    <xsl:template name="modules">
      <xsl:choose>
        <xsl:when test="Modules/*">
          <div class="element">
              <h2> Modules </h2>
              <ol><xsl:apply-templates select="/DataDocumenter/Modules/Module"/></ol>
          </div>
        </xsl:when>
    </xsl:choose>
    </xsl:template>

    <xsl:template match="/DataDocumenter/Modules/Module">
      <li><a href="{$root}{@src}{$ext}" class="ajax" data-target="#right"><xsl:value-of select="."/></a></li>
    </xsl:template>

    <!-- Object types -->
    <xsl:template name="objects">
      <xsl:choose>
        <xsl:when test="DatabaseObjects/*">
          <div class="element">
              <h2> Database objects </h2>
              <ol><xsl:apply-templates select="DatabaseObjects/Object"/></ol>
          </div>
        </xsl:when>
    </xsl:choose>
    </xsl:template>

    <xsl:template match="DatabaseObjects/Object">
      <xsl:choose>
        <xsl:when test="@count > 0">
          <li>
            <a href="{$root}{@src}{$ext}" class="ajax" data-target="#right">
              <xsl:value-of select="."/>
            </a> (<xsl:value-of select="@count"/>)
          </li>
        </xsl:when>
      </xsl:choose>
    </xsl:template>

</xsl:stylesheet>