﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>

  <xsl:variable name="root" select="'doc'"/>
  <xsl:variable name="content" select="'content'"/>
  <xsl:variable name="ext" select="''"/>
  <xsl:variable name="resources" select="''"/>

  <!-- Object localization in documentation -->
  <xsl:template match="Breadcrumbs">
    <div id="header" class="cf">
      <div id="breadcrumb" class="font-small">
        <xsl:apply-templates select="Breadcrumb"/>
      </div>
      <div id="tools">
        <div class="font-size">
          <a data-class="font-size-small" class="small"> A </a>
          <a data-class="font-size-medium" class="medium"> A </a>
          <a data-class="font-size-large" class="large"> A </a>
        </div>
      </div>
    </div>
    
    <xsl:if test="/DataDocumenter/LicenseTag">
       <div class="trial trial-content"> Generated with <a href="https://dataedo.com">Dataedo</a> (Trial) </div>
     </xsl:if>
  </xsl:template>

  
  <!-- Object localization in documentation element -->
  <xsl:template name="breadcrumb" match="Breadcrumb">
    <a href="#{@src}{$ext}" class="ajax" data-target="#right">
      <xsl:value-of select="."/>
    </a>

    <xsl:if test="position() != last()"> › </xsl:if>
  </xsl:template>

  <!-- Basic information about object -->
  <xsl:template name="objectInformation">
    <xsl:param name="objectType" />
    <xsl:param name="objectTypeFullDescription" />
    
    <xsl:variable name="icon">
      icon2x-<xsl:value-of select="$objectType"/>
    </xsl:variable>

    <h1 class="sticky-header">
      <i class="{$icon}" title="{$objectTypeFullDescription}"></i>
      <xsl:value-of select="DisplayName"/>
    </h1>

    <table class="table table-vertical">
      <tbody>
        <xsl:call-template name="row">
          <xsl:with-param name="name" select="'Documentation'"/>
          <xsl:with-param name="value" select="Documentation"/>
        </xsl:call-template>
        
        <xsl:call-template name="row">
          <xsl:with-param name="name" select="'Schema'"/>
          <xsl:with-param name="value" select="Schema"/>
        </xsl:call-template>

        <xsl:call-template name="row">
          <xsl:with-param name="name" select="'Name'"/>
          <xsl:with-param name="value" select="Name"/>
        </xsl:call-template>

        <xsl:if test="string-length(Title)>0">
          <xsl:call-template name="row">
            <xsl:with-param name="name" select="'Title'"/>
            <xsl:with-param name="value" select="Title"/>
            <xsl:with-param name="classes" select="'user-description'"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:choose>
          <xsl:when test="count(Modules/Module[not(Id = '-1')])=1">
            <xsl:variable name="src">
              <xsl:value-of select="$root"/>
              <xsl:text>/</xsl:text>
              <xsl:value-of select="DocumentationId"/>
              <xsl:text>/modules/</xsl:text>
              <xsl:value-of select="Modules/Module[not(Id = '-1')]/ObjectId"/>
              <xsl:text>/module</xsl:text>
            </xsl:variable>
            
            <xsl:call-template name="row">
              <xsl:with-param name="name" select="'Module'"/>
              <xsl:with-param name="src" select="$src"/>
              <xsl:with-param name="value" select="Modules/Module/Title"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="count(Modules/Module[not(Id = '-1')])>1">
            <xsl:variable name="documentationId">
              <xsl:value-of select="DocumentationId"/>
            </xsl:variable>
            
             <tr>
              <td>Modules</td>
              <td>
                <xsl:for-each select="Modules/Module[not(Id = '-1')]">
                  <xsl:variable name="src">
                    <xsl:value-of select="$root"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="$documentationId"/>
                    <xsl:text>/modules/</xsl:text>
                    <xsl:value-of select="ObjectId"/>
                    <xsl:text>/module</xsl:text>
                  </xsl:variable>
                  
                  <a href="#{$src}{$ext}" class="ajax" data-target="#right">
                    <xsl:value-of select="Title"/>
                  </a>
                  
                  <xsl:if test="position() != last()">, </xsl:if>
                </xsl:for-each>
              </td>
            </tr>
          </xsl:when>
        </xsl:choose>

        <xsl:call-template name="customFieldRows"/>
      </tbody>
    </table>

    <xsl:if test="Description and Description != ''">
      <div class="element description">
        <div class="html user-description">
          <xsl:value-of select="Description" disable-output-escaping="yes"/>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- Custom field data - rows -->
  <xsl:template name="customFieldRows" match="CustomFields/Data/CustomField
        | Documentation/CustomFields/Data/CustomField
        | Module/CustomFields/Data/CustomField">
    <xsl:param name="notEmptyOnly" select="true" />

    <xsl:for-each select="CustomFields/Data/CustomField
        | Documentation/CustomFields/Data/CustomField
        | Module/CustomFields/Data/CustomField">
      <xsl:call-template name="customFieldRow"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="customFieldRow" match="CustomFields/Data/CustomField
      | Documentation/CustomFields/Data/CustomField
      | Module/CustomFields/Data/CustomField">
    <xsl:param name="notEmptyOnly" select="true" />

    <xsl:if test="Value != '' or notEmptyOnly != 'true'">
      <tr>
        <td>
          <xsl:value-of select="Title"/>
        </td>
        <td class="user-description">
          <xsl:call-template name="insertHtmlNewLines">
            <xsl:with-param name="value" select="Value"/>
          </xsl:call-template>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Custom field definition -->
  <xsl:template name="customFieldColumnsHeaders" match="CustomFields/Definition/CustomField">
    <xsl:for-each select="CustomFields/Definition/CustomField">
      <xsl:call-template name="customFieldColumnsHeader"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="customFieldColumnsHeader" match="CustomFields/Data/CustomField">
    <th class="only-desktop">
      <xsl:value-of select="Title"/>
    </th>
  </xsl:template>

  <!-- Custom field data - columns -->
  <xsl:template name="customFieldColumnsData" match="CustomFields/Data">
    <xsl:for-each select="CustomFields/Data/CustomField">
      <xsl:call-template name="customFieldColumnData"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="customFieldColumnData" match="CustomFields/Data/CustomField">
    <td class="only-desktop user-description">
      <xsl:call-template name="insertHtmlNewLines">
        <xsl:with-param name="value" select="Value"/>
      </xsl:call-template>
    </td>
  </xsl:template>

  <!-- Custom field data - text -->
  <xsl:template name="customFieldColumnsText" match="CustomFields/Data">
    <xsl:param name="notEmptyOnly" select="true" />

    <xsl:for-each select="CustomFields/Data/CustomField">
      <xsl:call-template name="customFieldColumnText">
        <xsl:with-param name="notEmptyOnly" select="$notEmptyOnly"/>
        <xsl:with-param name="appendSeparator">
          <xsl:choose>
            <xsl:when test="not(position() = last())">
              <xsl:text>true</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>false</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="customFieldColumnText" match="CustomFields/Data/CustomField">
    <xsl:param name="notEmptyOnly" select="true" />
    <xsl:param name="appendSeparator" select="false" />
    <xsl:param name="separator" select="'&lt;br&gt;'" />

    <xsl:if test="Value != '' or notEmptyOnly != 'true'">
      <strong>
        <xsl:value-of select="Title"/>
      </strong>
      <xsl:text>: </xsl:text>
      <xsl:call-template name="insertHtmlNewLines">
        <xsl:with-param name="value" select="Value"/>
      </xsl:call-template>

      <xsl:if test="$appendSeparator = 'true'">
        <xsl:value-of select="$separator" disable-output-escaping="yes"/>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!-- Metadata -->
  <xsl:template name="metadata">
    <div style="margin-top: 15px">
      <span class="font-gray font-small font-small">
        Exported: <b><xsl:value-of select="Exported"/></b><xsl:if test="LastImported and LastImported != ''">, Last imported: <b><xsl:value-of select="LastImported"/></b></xsl:if>
      </span>
    </div>
  </xsl:template>

  <!-- Edition -->
  <xsl:template name="edition">
    <xsl:if test="/DataDocumenter/Edition">
      <div class="font-gray" style="margin-top: 15px">
        <xsl:value-of select="/DataDocumenter/Edition"/>
      </div>
    </xsl:if>
  </xsl:template>
  
  <!-- Row in information table -->
  <xsl:template name="row">
    <xsl:param name="name" />
    <xsl:param name="src" />
    <xsl:param name="value" />
    <xsl:param name="classes" />

    <xsl:if test="$value and $value != ''">
      <tr>
        <td>
          <xsl:value-of select="$name"/>
        </td>
        <xsl:choose>
          <xsl:when test="$src">
            <td>
              <a href="#{$src}{$ext}" class="ajax" data-target="#right">
                <xsl:value-of select="$value"/>
              </a>
            </td>
          </xsl:when>
          <xsl:otherwise>
            <td class="{$classes}">
              <xsl:value-of select="$value"/>
            </td>
          </xsl:otherwise>
        </xsl:choose>
      </tr>
    </xsl:if>
  </xsl:template>

  <!-- Inserts object name with title -->
  <xsl:template name="objectNameWithTitle">
    <xsl:param name="objectName" />
    <xsl:param name="objectTitle" />

    <xsl:value-of select="$objectName"/>
    <xsl:if test="string-length($objectTitle)>0">
      (<span class="user-description"><xsl:value-of select="$objectTitle"/></span>)
    </xsl:if>
  </xsl:template>

  <!-- Inserts new lines for HTML (<br/>) -->
  <xsl:template name="insertHtmlNewLines">
    <xsl:param name="value" />

    <xsl:choose>
      <!-- Return value if there is not new lines -->
      <xsl:when test="not(contains($value, '&#xA;'))">
        <xsl:value-of select="$value"/>
      </xsl:when>
      <xsl:otherwise>
        <!-- Return value before new line -->
        <xsl:value-of select="substring-before($value, '&#xA;')"/>
        
        <br/>

        <!-- Check new lines in rest of value -->
        <xsl:call-template name="insertHtmlNewLines">
          <xsl:with-param name="value" select="substring-after($value, '&#xA;')"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>