<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>

  <!-- Type of object for header -->
  <xsl:variable name="objectType" select="'Objects'"/>
    
  <!-- Root -->
  <xsl:template match="/DataDocumenter">
    <xsl:variable name="pathPart" select="Breadcrumbs/Breadcrumb[last()]/@src"/>
    <div data-page="{$pathPart}{$ext}">
      <xsl:apply-templates select="Breadcrumbs"/>
        
      <xsl:apply-templates select="Tables | Views | Functions | Procedures | Modules"/>
    </div>
  </xsl:template>

  <!-- List -->
  <xsl:template match="Tables | Views | Functions | Procedures | Modules">
    <xsl:choose>
      <xsl:when test="./*">
        <h1 class="sticky-header">
          <xsl:if test="(/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Module'])[1] != ''">
            <xsl:value-of select="(/DataDocumenter/Breadcrumbs/Breadcrumb[@type='Module'])[1]"/>:
          </xsl:if>

          <xsl:value-of select="$objectType"/>
        </h1>

        <table class="table">
          <thead>
            <th></th>
            <th></th>
            <th>Name</th>

            <xsl:call-template name="customFieldColumnsHeaders"/>
          </thead>
          <tbody>
            <xsl:apply-templates select="Table | View | Function | Procedure | Module"/>
          </tbody>
        </table>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- List element -->
  <xsl:template match="Table | View | Function | Procedure">
    <xsl:variable name="title">
      <xsl:value-of select="ObjectTypeFullDescription"/>
    </xsl:variable>

    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>

      <td>
        <xsl:variable name="icon">
          icon-<xsl:value-of select="ObjectTypeFull"/>
        </xsl:variable>
      
        <i class="{$icon} no-margin" title="{$title}"></i>
      </td>

      <td class="display-name">
        <a href="#{Src}{$ext}" class="ajax" data-target="#right">
          <xsl:value-of select="DisplayName"/>
        </a>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>
  </xsl:template>

  <xsl:template match="Module">
    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>

      <td>
        <i class="icon-module no-margin" title="Module"></i>
      </td>

      <td>
        <a href="#{Src}{$ext}" class="ajax" data-target="#right">
          <xsl:value-of select="Title"/>
        </a>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>
  </xsl:template>

</xsl:stylesheet>