<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
    
    <xsl:output method="html" encoding="utf-8" doctype-system="about:legacy-compat"/>

  <!-- Default template -->
  <xsl:template match="*"></xsl:template>

  <!-- Redirection -->
  <xsl:template match="/DataDocumenter">
    
      <html>
          <head>
            <meta charset="utf-8"/>
            <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
            <meta name="viewport" content="width=device-width, initial-scale=1"/>

            <meta http-equiv="cache-control" content="no-cache, no-store, must-revalidate" />
            <meta http-equiv="pragma" content="no-cache" />
            <meta http-equiv="expires" content="0" />
            <meta name="cache-pool-id" content="{/DataDocumenter/CachePoolId}" />

            <title>
              <xsl:value-of select="Global/DocumentTitle"/>
            </title>

            <link href="{$resources}favicon.ico" rel="icon"/>
            <link href="{$resources}favicon.ico" rel="shortcut icon"/>
            <link rel="stylesheet" href="{$resources}lib/Google Fonts/style.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}lib/jQueryUI/jquery-ui-1.9.2.custom.min.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}css/reset.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}css/default.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}css/layout.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}css/inline-html.css?v={/DataDocumenter/CachePoolId}"/>
            <link rel="stylesheet" href="{$resources}css/user.css?v={/DataDocumenter/CachePoolId}"/>
            
            <xsl:call-template name="scripts"/>
          </head>

          <body class="font-size-medium">
            <div id="nav-toggle"></div>
            <xsl:call-template name="main"/>
          </body>
        </html>
    </xsl:template>

    <!-- Header -->
    <xsl:template name="header">
      <nav id="nav" class="grid">
          <div class="span12">
            <a href="#index" class="ajax logo" data-target="#right">
              <img src="{$resources}img/logo.png"/>
            </a>

            <div class="menu"></div>
            <h3 class="docname font-medium">
              <xsl:value-of select="/DataDocumenter/Global/DocumentTitle"/>
              <xsl:if test="/DataDocumenter/LicenseTag">
                <span class="trial trial-header"> Trial </span>
              </xsl:if>
          </h3>
          </div>
      </nav>
    </xsl:template>

    <!-- Content -->
    <xsl:template name="main">
      <div id="main" class="cf">
        <xsl:call-template name="infobar"/>
        <xsl:call-template name="nav-tree"/>
        <xsl:call-template name="content"/>
      </div>
    </xsl:template>

  <xsl:template name="infobar">
    <div id="infobar" class="only-mobile">
      <a href="#index" class="ajax logo" data-target="#right">
        <img src="{$resources}img/logo.png"/>
      </a>

      <h3 class="docname font-medium">
        <xsl:value-of select="/DataDocumenter/Global/DocumentTitle"/>
      </h3>
    </div>
  </xsl:template>

    <!-- Tree Search -->
    <xsl:template name="search">
      <div class="search-box -with-pattern">
        <input class="search-input" id="search-input" type="text" />
        <label class="search-icon" for="search-input"></label>
        
        <i class="search-options-btn"></i>
        <div class="search-options-dropdown font-small">
          <div class="search-options-dropdown-group">
            <label>
              <input type="checkbox" disabled="disabled" checked="checked"/> Search object names
            </label>
          </div>
          <div class="search-options-dropdown-group">
            <label>
              <input type="checkbox" data-search="columns"/> Search column names
            </label>
          </div>
        </div>
      </div>
    </xsl:template>

  <!-- Navigation -->
  <xsl:template name="nav-tree">
    <div id="aside" class="resizable-left border-right">
          <div id="left">
          <xsl:call-template name="header"/>
       <xsl:call-template name="search"/>

           <xsl:choose>
             <xsl:when test="Databases/Database">
               <ul class="tree">
                 <li>
                   <ul>
                     <xsl:apply-templates select="Databases/Database"/>
                   </ul>
                 </li>
               </ul>
             </xsl:when>
             <xsl:otherwise>
               <strong> Error: </strong> documentations not found.
             </xsl:otherwise>
           </xsl:choose>
         </div>
         
         <div id="left-footer"> 
           Generated with <strong><a href="{Global/Product/@src}"><xsl:value-of select="Global/Product"/></a></strong>

           <xsl:if test="/DataDocumenter/LicenseTag">
             <!-- Trial -->
             <script src="https://dataedo.com/asset/js/html-export-popup.js?v={/DataDocumenter/CachePoolId}"
                     data-hep-header="Like what you see?"
                     data-hep-text="Tell your friends about it!"
                     data-hep-btn-share="true"
                     data-hep-delay="1000"
                     data-hep-gtm="true">
             </script>
           </xsl:if>
         </div>
     </div>
  </xsl:template>

  <!-- Navigation - folders -->
  <xsl:template match="Modules|Functions|Procedures|Tables|Views">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test="*"> expand </xsl:when>
      </xsl:choose>
    </xsl:variable>

    <li class="{$class}">
      <i class="icon-folder"></i>
      <a class="ajax" data-target="#right" href="#{@src}{$ext}"><xsl:value-of select="local-name()"/></a>
      <ul style="display: none;">
        <xsl:apply-templates select="*"/>
      </ul>
    </li>
  </xsl:template>

  <!-- Navigation - objects -->
  <xsl:template match="Database|Module|Function|Procedure|Table|View">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test="*"> expand </xsl:when>
      </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="icon">
      icon-<xsl:value-of select="@objectFullType"/>
    </xsl:variable>

    <xsl:variable name="title">
      <xsl:value-of select="@objectTypeFullDescription"/>
    </xsl:variable>

    <li class="{$class}">
      <i class="{$icon}" title="{$title}"></i>
      <a class="ajax" data-target="#right" href="#{@src}{$ext}"><xsl:value-of select="@name"/></a>
      <ul style="display: none;">
        <xsl:apply-templates select="*"/>
      </ul>
    </li>
  </xsl:template>

  <!-- Content -->
  <xsl:template name="content">
    <div id="content" class="resizable-right">
      <div id="right">
        <div style="text-align: center; padding: 80px 20px;">Loading, please wait... <img src="img/icons/loader.gif"/></div>
      </div>
      <xsl:call-template name="documentations-list"/>
      <xsl:call-template name="footer"/>
    </div>
  </xsl:template>

  <xsl:template name="documentations-list">
    <div data-page="index{$ext}">
      <xsl:apply-templates select="Breadcrumbs"/>

      <h1 class="sticky-header"> Repository </h1>
      <ol type="1">
        <xsl:for-each select="Databases/Database">
          <li>
            <a href="#{@src}{$ext}" class="ajax" data-target="#right">
              <xsl:value-of select="@name"/>
            </a>
          </li>
        </xsl:for-each>
      </ol>
    </div>
  </xsl:template>

    <!-- Footer -->
    <xsl:template name="footer">
      <footer class="footer font-gray font-small cf">
        <xsl:if test="/DataDocumenter/Edition">
          <span style="float: left">
               <xsl:value-of select="/DataDocumenter/Edition"/>
          </span>
        </xsl:if>
        <span style="float:right"> Generated with <strong><a href="{Global/Product/@src}"><xsl:value-of select="Global/Product"/></a></strong></span>
      </footer>
    </xsl:template>

    <!-- Extra scripts -->
    <xsl:template name="scripts">
      <div id="popup-error"> Action cannot be finished </div>
      <div id="binding"></div>
      <script src="{$resources}lib/jQuery/jquery-1.11.3.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}lib/jQueryUI/jquery-ui-1.9.2.custom.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}lib/iframeResizer/client.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}lib/Store.js/store.legacy.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}lib/fuse.js/fuse.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}lib/throttle-debounce/throttle-debounce.min.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/sticky.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/url.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/tables.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/loader.single.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/treeExpand.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/utilities.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/mobile.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/dependenciesTree.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/search.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/userLinks.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/erd.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="search.json.js?v={/DataDocumenter/CachePoolId}"></script>
      <script src="{$resources}js/user.js?v={/DataDocumenter/CachePoolId}"></script>
    </xsl:template>

</xsl:stylesheet>