<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt">
  <xsl:include href="_common.xsl"/>
  
  <xsl:template match="/DataDocumenter">
    <xsl:variable name="pathPart" select="Breadcrumbs/Breadcrumb[last()]/@src"/>
      <div data-page="{$pathPart}{$ext}">
        <div class="container">
          <xsl:apply-templates select="Breadcrumbs"/>
                
          <xsl:call-template name="module"/>
          <xsl:apply-templates select="Functions|Procedures|Tables|Views"/>
        </div>
      </div>
  </xsl:template>

  <!-- Module information -->
  <xsl:template name="module">
    <h1 class="sticky-header">
      <!--<i class="icon2x-module"></i>-->
      <xsl:value-of select="Module/Name"/>
    </h1>

    <table class="table table-vertical">
      <tbody>
          <xsl:call-template name="customFieldRows"/>
      </tbody>
    </table>

    <xsl:if test="Module/ERD != ''">
      <div class="scroll-x">
        <xsl:value-of select="Module/ERD" disable-output-escaping="yes"/>
    </div>
      <script src="{$resources}js/popup.js"></script>
      <script>
        <![CDATA[
          $(function() {
            $('svg [data-msg]').popup();
          });
        ]]>
      </script>
    </xsl:if>

    <xsl:if test="Module/Description != ''">
      <div class="element description">
        <!-- The disable-output-escaping="yes" provides HTML content support. -->
        <div class="html user-description">
          <xsl:value-of select="Module/Description" disable-output-escaping="yes"/>
        </div>
      </div>
    </xsl:if>
  </xsl:template>

  <!-- Custom field -->
  <xsl:template match="Module/CustomFields/Data/CustomField">
    <tr>
      <td>
        <xsl:value-of select="Title"/>
      </td>
      <td class="user-description">
        <xsl:value-of select="Value"/>
      </td>
    </tr>
  </xsl:template>

  <!-- Objects' tables -->
  <xsl:template match="Functions|Procedures|Tables|Views">
    <xsl:choose>
      <xsl:when test=".!=''">
        <xsl:variable name="localName">
          <xsl:value-of select="local-name()"/>
        </xsl:variable>
        
        <div class="collapsible" data-key="{$localName}">
          <div class="collapsible-link font-large font-bold">
            <xsl:value-of select="$localName"/>
          </div>

          <div class="collapsible-area">
            <table class="table">
              <thead>
                <th style="width: 40px !important"></th>
                <th style="width: 40px !important"></th>
                <th>Name</th>

                <xsl:call-template name="customFieldColumnsHeaders"/>
              </thead>
              <tbody>
                <xsl:apply-templates select="Row"/>
              </tbody>
            </table>
          </div>
        </div>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!-- Objects row -->
  <xsl:template match="Row">
    <xsl:variable name="title">
      <xsl:value-of select="ObjectTypeFullDescription"/>
    </xsl:variable>

    <tr>
      <td>
        <xsl:value-of select="OrdinalPosition"/>
      </td>

      <td>
        <xsl:variable name="icon">
          icon-<xsl:value-of select="ObjectTypeFull"/>
        </xsl:variable>

        <i class="{$icon}" title="{$title}"></i>
      </td>

      <td class="display-name">
        <a href="#{Name/@src}{$ext}" class="ajax" data-target="#right">
          <xsl:value-of select="DisplayName"/>
        </a>
      </td>

      <xsl:call-template name="customFieldColumnsData"/>
    </tr>
  </xsl:template>

</xsl:stylesheet>